<?php
/**
 * Load assets
 *
 * @author      WisdmLabs
 * @version     2.0.0
 */

namespace wisdmlabs\cpb;

if (! defined('ABSPATH')) {
    exit;
}

if (! class_exists('WdmCPBAdminAssets')) :

    /**
     * WdmCPBAdminAssets Class is responsible for enqueuing scripts and styles for
     * CPB admin side.
     */
    class WdmCPBAdminAssets
    {
        /**
         * Adds action for enqueuing scripts and styles for CPB Admin side.
         */
        public function __construct()
        {
            add_action('admin_enqueue_scripts', array($this, 'wdmLoadAdminCss'));
            add_action('admin_enqueue_scripts', array($this, 'wdmLoadAdminScripts'), 9);
            add_action('admin_head-post.php', array($this, 'wdmPublishAdminHook'));
            add_action('admin_head-post-new.php', array($this, 'wdmPublishAdminHook'));
            add_action('woocommerce_product_options_pricing', array($this, 'hideRegularPrice'));
        }


        public function hideRegularPrice()
        {
            global $woo_wdm_bundle;
            wp_enqueue_script(
                'wdm-regular-price',
                $woo_wdm_bundle->wooWdmBundlesPluginUrl() . '/assets/js/wdm_regular_price.js',
                array('jquery'),
                CPB_VERSION
            );
        }

        /**
        * Enqueue the required styles for admin side of CPB.
        */
        public function wdmLoadAdminCss()
        {
            global $woo_wdm_bundle;
            $screen       = get_current_screen();
            $screen_id    = $screen ? $screen->id : '';
            if (in_array($screen_id, array('product', 'edit-product'))) {
                // Register admin styles
                wp_register_style('wdm-bundle-admin-css', $woo_wdm_bundle->wooWdmBundlesPluginUrl() . '/assets/css/bundles-admin.css', array(), CPB_VERSION);
                wp_enqueue_style(
                    'wdm-alpha-color-picker-css',
                    $woo_wdm_bundle->wooWdmBundlesPluginUrl() . '/assets/css/alpha-color-picker.css',
                    array('wp-color-picker'),
                    CPB_VERSION
                );
                wp_enqueue_style('cpb-select2-css', $woo_wdm_bundle->wooWdmBundlesPluginUrl() . '/assets/css/cpb-select2.css', array(), CPB_VERSION);
                wp_enqueue_style('cpb-product-selection-css', $woo_wdm_bundle->wooWdmBundlesPluginUrl() . '/assets/css/products-selection.css', array(), CPB_VERSION);
                wp_enqueue_style('wdm-bundle-admin-css');
                wp_enqueue_style('wdm-alpha-color-picker-css');
            }

            if (isset($_GET['page']) && $_GET['page'] == "custom_product_boxes_view") {
                wp_enqueue_style('cpb-settings-page-css', $woo_wdm_bundle->wooWdmBundlesPluginUrl() . '/assets/css/wdm-cpb-settings-page.css', array(), CPB_VERSION);
                wp_enqueue_style('woocommerce_admin_styles', plugin_dir_url(dirname(dirname(__FILE__))).'woocommerce/assets/css/admin.css');
                wp_enqueue_style('woocommerce-admin-css', $woo_wdm_bundle->wooWdmBundlesPluginUrl() . '/assets/css/woocommerce-admin.css', array(), CPB_VERSION);
            }
        }

        /**
        * Gets the current screen if it is edit/create product.
        * Enqueue the scripts required for the admin side of CPB
        */
        public function wdmLoadAdminScripts()
        {
            global $woo_wdm_bundle;

            // If wdm_cpb is already set for another product
            // if (isset($_SESSION['wdm_cpb'])) {
            //     unset($_SESSION['wdm_cpb']);
            // }

            if (get_option('wdmcpb_settings_notice_dismissed') != 1) {
                wp_enqueue_script('cpb-dismiss-notice', $woo_wdm_bundle->wooWdmBundlesPluginUrl() . '/assets/js/wdm-cpb-dismiss-notice.js', array('jquery'), CPB_VERSION, true);
                wp_localize_script('cpb-dismiss-notice', 'wdmcpb_notice_object', array(
                    'ajax_url' => admin_url('admin-ajax.php'),
                ));
            }

            if (isset($_GET['page']) && $_GET['page'] == "custom_product_boxes_view") {
                wp_register_script('cpb-settings-page-js', $woo_wdm_bundle->wooWdmBundlesPluginUrl() . '/assets/js/wdm-cpb-settings-page.js', array('jquery'), CPB_VERSION);
                wp_enqueue_script('cpb-settings-page-js');
                wp_enqueue_script('jquery-tiptip', WC()->plugin_url() . '/assets/js/jquery-tiptip/jquery.tipTip.min.js', array('jquery'), WC_VERSION, true);
            }

            $this->loadEditProductPageScripts();
            // if (in_array($screen_id, array('product', 'edit-product'))) {
            //     wp_enqueue_script('jquery');
            //     wp_register_script('wdm-product-type-cpb', $woo_wdm_bundle->wooWdmBundlesPluginUrl() . '/assets/js/wdm-product-type-cpb.js', array('jquery'), CPB_VERSION);
            //     wp_register_script(
            //         'wdm-alpha-color-picker',
            //         $woo_wdm_bundle->wooWdmBundlesPluginUrl() . '/assets/js/alpha-color-picker.js',
            //         array('jquery', 'wp-color-picker'),
            //         CPB_VERSION,
            //         true
            //     );
            //     wp_localize_script('wdm-product-type-cpb', 'ajax_object', array(
            //         'ajax_url' => admin_url('admin-ajax.php'),
            //         'product_id' => isset($post->ID) ? $post->ID : 0,
            //     ));
            //     wp_enqueue_script('wdm-alpha-color-picker');
            //     wp_enqueue_script('wdm-product-type-cpb');
            //     wp_register_script('wdm-cpb-settings-js', $woo_wdm_bundle->wooWdmBundlesPluginUrl() . '/assets/js/wdm-cpb-settings.js', array('jquery'), CPB_VERSION);

            //     $this->enqueueProductSearchScripts();
            // }
        }

        /*
         * Loads scripts to be loaded on edit product page
         */
        public function loadEditProductPageScripts()
        {
            global $post, $woo_wdm_bundle;

            if (!isEditProductPage()) {
                return;
            }

            wp_enqueue_script('jquery');
            wp_register_script('wdm-product-type-cpb', $woo_wdm_bundle->wooWdmBundlesPluginUrl() . '/assets/js/wdm-product-type-cpb.js', array('jquery'), CPB_VERSION);
            wp_register_script(
                'wdm-alpha-color-picker',
                $woo_wdm_bundle->wooWdmBundlesPluginUrl() . '/assets/js/alpha-color-picker.js',
                array('jquery', 'wp-color-picker'),
                CPB_VERSION,
                true
            );
            wp_localize_script('wdm-product-type-cpb', 'ajax_object', array(
                'ajax_url' => admin_url('admin-ajax.php'),
                'product_id' => isset($post->ID) ? $post->ID : 0,
            ));
            wp_enqueue_script('wdm-alpha-color-picker');
            wp_enqueue_script('wdm-product-type-cpb');
            wp_register_script('wdm-cpb-settings-js', $woo_wdm_bundle->wooWdmBundlesPluginUrl() . '/assets/js/wdm-cpb-settings.js', array('jquery'), CPB_VERSION, true);

            $this->enqueueProductSearchScripts();

            if (!isSubscriptionActive()) {
                return;
            }

            wp_register_script('wdm-cpb-subscription', $woo_wdm_bundle->wooWdmBundlesPluginUrl() . '/assets/js/subscriptions/wdm-cpb-subscriptions-admin.js', array('jquery'), CPB_VERSION);
            // wp_localize_script('wdm-cpb-subscription', 'wdm_subscriptions_object', array(
            //     'ajax_url' => admin_url('admin-ajax.php'),
            //     'isSubscriptionActive'  => isSubscriptionActive(),
            //     'product_id' => isset($post->ID) ? $post->ID : 0,
            // ));
            wp_enqueue_script('wdm-cpb-subscription');
        }

        /**
        * This function enques all the js related to product search for add-on products
        */
        public function enqueueProductSearchScripts()
        {
            global $woo_wdm_bundle;

            wp_register_script('wdm-cpb-select2', $woo_wdm_bundle->wooWdmBundlesPluginUrl() . '/assets/js/cpb-select2.js', array('jquery'), CPB_VERSION);
            wp_enqueue_script('wdm-cpb-select2');
            wp_register_script('wdm-cpb-extended-select', $woo_wdm_bundle->wooWdmBundlesPluginUrl() . '/assets/js/enhanced-select-extended.js', array('jquery'), CPB_VERSION);
            wp_enqueue_script('wdm-cpb-extended-select');

            wp_localize_script('wdm-cpb-extended-select', 'wdm_enhanced_select_params', array(
                'i18n_matches_1' => _x('One result is available, press enter to select it.', 'enhanced select', 'woocommerce'),
                'i18n_matches_n' => _x('%qty% results are available, use up and down arrow keys to navigate.', 'enhanced select', 'woocommerce'),
                'i18n_no_matches' => _x('No matches found', 'enhanced select', 'woocommerce'),
                'i18n_ajax_error' => _x('Loading failed', 'enhanced select', 'woocommerce'),
                'i18n_input_too_short_1' => _x('Please enter 1 or more characters', 'enhanced select', 'woocommerce'),
                'i18n_input_too_short_n' => _x('Please enter %qty% or more characters', 'enhanced select', 'woocommerce'),
                'i18n_input_too_long_1' => _x('Please delete 1 character', 'enhanced select', 'woocommerce'),
                'i18n_input_too_long_n' => _x('Please delete %qty% characters', 'enhanced select', 'woocommerce'),
                'i18n_selection_too_long_1' => _x('You can only select 1 item', 'enhanced select', 'woocommerce'),
                'i18n_selection_too_long_n' => _x('You can only select %qty% items', 'enhanced select', 'woocommerce'),
                'i18n_load_more' => _x('Loading more results&hellip;', 'enhanced select', 'woocommerce'),
                'i18n_searching' => _x('Searching&hellip;', 'enhanced select', 'woocommerce'),
                'ajax_url' => admin_url('admin-ajax.php'),
                'search_products_nonce' => wp_create_nonce('search-products'),
            ));
        }
        
        /**
        * This function enqueues the scripts for the CPB Product publish time.
        * It handles the CPB Admin settings.
        * Prepare the data for localization for the error handling of CPB settings.
        */
        public function wdmPublishAdminHook()
        {
            global $post, $woo_wdm_bundle;

            if (is_admin() && $post->post_type == 'product') {
                wp_enqueue_script('wdm-publish-admin-hook', plugins_url('/assets/js/wdm-publish-admin-hook.js', dirname(__FILE__)), array('jquery'));
                wp_localize_script('wdm-publish-admin-hook', 'cpb_settings_object', array(
                    'text_box_quantity'   => __('Please enter value in "Box Quantity" field under the Custom Box Settings.', 'custom-product-boxes'),
                    'text_addon_products'           => __('Please enter value in "Add-On Products" field.', 'custom-product-boxes'),
                    'text_regular_price'     => __('Please enter valid value in "Regular Price" field.', 'custom-product-boxes'),
                    'text_subscription_price'     => __('Please enter valid value in "Subscription Price" field.', 'custom-product-boxes'),
                    'text_signup_fee'     => __('Please enter valid value in "Signup Fee" field.', 'custom-product-boxes'),
                    'text_trial_period'     => __('Please enter valid value in "Free Trial" field.', 'custom-product-boxes'),
                    'text_sale_price'    => __('Please enter valid value in "Sale Price" field which should be less than regular price.', 'custom-product-boxes')
                ));

                $enablePrefillProducts = get_post_meta(get_the_ID(), 'wdm_prefilled_box', true);
                wp_enqueue_script('wdm-cpb-function', $woo_wdm_bundle->wooWdmBundlesPluginUrl() . '/assets/js/functions.js', false);
                //Handles the pre-filled products for the CPB.
                wp_enqueue_script('wdm-prefilled-products-cpb', $woo_wdm_bundle->wooWdmBundlesPluginUrl() . '/assets/js/wdm-cpb-prefilled-products.js', false);
                //Localization data for pre-filled products section of CPB.
                wp_localize_script('wdm-prefilled-products-cpb', 'cpb_prefilled_object', array(
                    'ajax_url' => admin_url('admin-ajax.php'),
                    'add_image'       => $woo_wdm_bundle->wooWdmBundlesPluginUrl() .'/assets/images/plus-icon.png',
                    'remove_image'    => $woo_wdm_bundle->wooWdmBundlesPluginUrl() .'/assets/images/minus-icon.png',
                    'enablePrefillProducts' => $enablePrefillProducts,
                    'total_prefill_qty_text' => __("Total quantity of products selected for pre filled boxes should be lesser than or equal to CPB box quantity", 'custom-product-boxes'),
                    'sld_ind_text'  => __('Quantity of product(s) sold individually cannot be more than 1. Please change the quantity of the following product(s): ', 'custom-product-boxes'),
                    'qty_greater_zero'  => __('Quantity of prefilled product should be greater than 1. Please change the quantity of products', 'custom-product-boxes'),
                ));
            }
        }
    }

endif;

return new WdmCPBAdminAssets();
