<?php

namespace wisdmlabs\cpb;

/**
* This class creates setting page for CPB
*/
class WdmCpbSettingPage
{
    public function __construct()
    {
        add_action('admin_notices', array($this, 'newSettingsPageNotice'), 10);
        add_action('admin_menu', array($this, 'cpbMenuPage'), 10);
        add_action('wp_ajax_wdmcpb_dismiss_settings_notice', array($this, 'updateSettingsNoticeDismissalFlag'));
    }

    public function cpbMenuPage()
    {
        add_menu_page('CPB Administration', 'CPB Settings', 'manage_options', 'custom_product_boxes_view', array($this, 'cpbSettings'));
    }

    public function cpbSettings()
    {
        if (isset($_POST['cpb_settings_field']) && wp_verify_nonce($_POST['cpb_settings_field'], 'cpb_settings_action')) {
            $this->saveSettings();
        }

        add_action('wdm_show_privacy_settings', array($this, 'showPrivacySettings'), 10);
        $this->showSettings();
    }

    public function updateSettingsNoticeDismissalFlag()
    {
        update_option('wdmcpb_settings_notice_dismissed', 1);
        die();
    }

    public function getLabelString()
    {
        $existingLabels = getExistingMsgLabels();

        if (!empty($existingLabels)) {
            update_option('wdmcpb_old_order_labels', $existingLabels);
        }

        return implode(", ", $existingLabels);
    }

    /**
    * Show the admin notices for settings page.
    */
    public function newSettingsPageNotice()
    {
        if (isset($_GET['page']) && $_GET['page'] == 'custom_product_boxes_view') {
            return;
        }

        $settingsUrl = menu_page_url('custom_product_boxes_view', false);
        $hereText = '<a href = "'.$settingsUrl.'">'.__('here', 'custom-product-boxes').'</a>';
        $pluginName = '<strong>'.__('Custom Product Boxes', 'custom-product-boxes').'</strong>';
        $settingsNoticeDismissalFlag = get_option('wdmcpb_settings_notice_dismissed', 0);
        if ($settingsNoticeDismissalFlag != 1) {
            ?>
            <div class="notice notice-warning wdmcpb-settings-notice is-dismissible" >
                <p><?php echo sprintf(__('%s plugin has added a new settings page, which contains privacy settings. Please check the page %s.', 'custom-product-boxes'), $pluginName, $hereText); ?></p>
            </div>
            <?php
        }
    }

    public function showPrivacySettings()
    {
        $disableSetting = "";
        $settingMsg = "";
        $hide_labels = "";
        $trClasses = "wdmcpb_labels";
        $msgDeletionNote = "";
        $labelString = "";

        if (is_callable('WC') && version_compare(WC_VERSION, '3.4', '<')) {
            $disableSetting = "disabled";
            $settingMsg = __('Setting unavailable because woocommerce version is lower then 3.4', 'custom-product-boxes');
            $hide_labels = 'display:none;';
        }

        $orderNumber = getLastOrderNumber();

        if (!isCpbFreshInstall() && hasWcOrders() && $orderNumber) {
            $labelString = $this->getLabelString();

            $msgDeletionNote = sprintf(__("Gift box messages of orders above order #%s will be automatically detected to work seamlessly with new export tool and removal personal data tool of WordPress. BUT you will have to help the system for orders below #%s to make them work with export tool and personal data tool. Kindly, add gift message labels used for those orders. Multiple labels can be added by using comma(,) as a separator.", 'custom-product-boxes'), $orderNumber, $orderNumber);
        } else {
            $trClasses .= " wdmcpb_labels_hide";
            $hide_labels = 'display:none;';
            // while pushing to git unused, but used in included file
            unset($msgDeletionNote);
            unset($labelString);
        }

        include_once('wdm-cpb-privacy-settings-html.php');
    }

    public function showSettings()
    {
        include_once('wdm-cpb-settings-html.php');
    }

    public function saveSettings()
    {
        if (!isset($_POST['_wdm_enable_giftbox_total'])) {
            $_POST['_wdm_enable_giftbox_total'] = 'off';
        }
        if (!isset($_POST['_wdm_enable_addbox_total'])) {
            $_POST['_wdm_enable_addbox_total'] = 'off';
        }
        if (!isset($_POST['_wdmcpb_anonymize_mgs'])) {
            $_POST['_wdmcpb_anonymize_mgs'] = 'off';
        }
        if (!isset($_POST['_wdm_hide_stock'])) {
            $_POST['_wdm_hide_stock'] = 'off';
        }

        $msgLabels = $this->getLabelString();

        $default_data = array(
           '_grand_total_label' => __('Grand Total', 'custom-product-boxes'),
           '_wdm_enable_giftbox_total' => 'on',
           '_giftbox_total_label' => __('Box Total', 'custom-product-boxes'),
           '_wdm_enable_addbox_total' => 'on',
           '_addbox_total_label' => __('Box Charges', 'custom-product-boxes'),
           '_wdmcpb_anonymize_mgs' => 'off',
           '_wdm_hide_stock' => 'off',
           'wdmcpb_old_order_labels' => $msgLabels,
        );
                       
        $cpb_settings = shortcode_atts($default_data, $_POST);

        foreach ($cpb_settings as $key => $value) {
            if ($key == 'wdmcpb_old_order_labels') {
                $msgArray = array_map('trim', explode(',', $value));
                update_option('wdmcpb_old_order_labels', $msgArray);
                continue;
            }
            update_option($key, $value);
        }

        include_once('wdm-cpb-update-nav.php');
    }
}
