<?php
namespace wisdmlabs\cpb;

if (!defined('ABSPATH')) {
    exit;
}

if (!class_exists('WdmCPBProductSubscription')) {
    class WdmCPBProductSubscription
    {
        public function __construct()
        {
            add_filter('woocommerce_is_subscription', array($this, 'isSubscription'), 10, 3);
            add_action('woocommerce_checkout_subscription_created', array($this, 'cpbAddToSubscription'), 10, 1);
            add_filter('wcs_view_subscription_actions', array($this, 'hideChangeAddress'), 10, 2);
            add_filter('wcs_can_items_be_removed', array($this, 'addonCantBeRemoved'), 10);
            add_filter('single_add_to_cart_text', array($this, 'singleAddToCartText'), 10, 2);
            add_filter('bundle_add_to_cart_text', array($this, 'singleAddToCartText'), 10, 2);
        }

        /*
         * Function to disable remove button on subscriptions
         * $allow boolean allow the remove button
         * $subscription WC_Subscription Object holds the Subscription data.
         */
        public function addonCantBeRemoved()
        {
            return false;
        }

        public function hideChangeAddress($actions, $subscription)
        {
            if ($subscription && subscriptionContainsCPB($subscription)) {
                unset($actions['change_address']);
                return $actions;
            }

            return $actions;
        }

        /*
		 * Function to add CPB data in subscriptions object
         */
        public function cpbAddToSubscription($subscription)
        {
            global $woocommerce;
            $box_ids = array();

            $line_items = $subscription->get_items();
            foreach ($line_items as $key => $sub_item) {
                unset($key);
                if ($sub_item['product_id']) {
                    $box = wc_get_product($sub_item['product_id']);
                    if ($box->is_type('wdm_bundle_product')) {
                        array_push($box_ids, $box->get_id());
                    }
                }
            }
            $items = $woocommerce->cart->get_cart();
            foreach ($items as $item => $cart_item) {
                unset($item); //unused
                $this->addItemsToSubscription($cart_item, $box_ids, $subscription);
            }
        }

        public function addItemsToSubscription($cart_item, $box_ids, $subscription)
        {
            $cpb_id = 0;

            if (isset($cart_item['subscription_resubscribe']) && isset($cart_item['wdm_bundled_items'])) {
                $cpb_id = $cart_item['product_id'];
            }

            if (isset($cart_item['wdm_custom_bundled_by']) && ! empty($cart_item['wdm_custom_bundled_by']) && in_array($cart_item['bundle_cpb_id'], $box_ids) && get_post_meta($cart_item['bundle_cpb_id'], 'wdm_enable_product_subscription', true) == 'yes') {
                $item_id = $subscription->add_product(
                    $cart_item['data'],
                    $cart_item['quantity'],
                    array(
                        'variation' => $cart_item['variation'],
                        'totals'    => array(
                            'subtotal'     => $cart_item['line_subtotal'],
                            'subtotal_tax' => $cart_item['line_subtotal_tax'],
                            'total'        => $cart_item['line_total'],
                            'tax'          => $cart_item['line_tax'],
                            'tax_data'     => $cart_item['line_tax_data'],
                        ),
                    )
                );
                wc_add_order_item_meta($item_id, __('Included with', 'custom-product-boxes'), get_the_title($cart_item['bundle_cpb_id']));
            }

            if (isset($cart_item['subscription_resubscribe']) && isset($cart_item['subscription_resubscribe']['custom_line_item_meta']) && !empty($cart_item['subscription_resubscribe']['custom_line_item_meta']) && isset($cart_item['subscription_resubscribe']['custom_line_item_meta']['Included with'])) {
                $item_id = $subscription->add_product(
                    $cart_item['data'],
                    $cart_item['quantity'],
                    array(
                        'variation' => $cart_item['variation'],
                        'totals'    => array(
                            'subtotal'     => $cart_item['line_subtotal'],
                            'subtotal_tax' => $cart_item['line_subtotal_tax'],
                            'total'        => $cart_item['line_total'],
                            'tax'          => $cart_item['line_tax'],
                            'tax_data'     => $cart_item['line_tax_data'],
                        ),
                    )
                );
                wc_add_order_item_meta($item_id, __('Included with', 'custom-product-boxes'), $cart_item['subscription_resubscribe']['custom_line_item_meta']['Included with']);
            }
        }

        /*
		 * Callback Function which allows subscription module to work on the wdm_bundle_product.
		 * i.e; returns true if wdm_bundle_product is a subscription product or not.
         */
        public function isSubscription($is_subscription, $product_id, $product)
        {
            unset($product_id); // unused
            if (!$product->is_type('wdm_bundle_product')) {
                return $is_subscription;
            }

            return $product->is_type('wdm_bundle_product') && $product->contains_sub;
        }


        /*
		 *
        */
        public function singleAddToCartText($text, $product)
        {
            if ($product->contains_sub()) {
                $text = get_option('woocommerce_subscriptions_add_to_cart_button_text');
            }
            return !empty($text) && $text ? $text : __("Sign Up Now", 'custom-product-boxes');
        }
    }
    $cpbSubscription = new WdmCPBProductSubscription();
}
