<?php

if (!defined('ABSPATH')) {
    exit; // Exit if accessed directly
}

if (! function_exists('printAdminNotices')) {
    function printAdminNotices($message, $class)
    {
        if (current_user_can('activate_plugins')) {
            ?>
            <div id="message" class="<?php echo $class; ?>">
            <?php echo "<p>".$message."</p>"; ?>
            </div>
            <?php
        }
    }
}

if (! function_exists('cpb_addon_base_plugin_inactive_notice')) {
    /**
    * Displays an admin notice if the woocommerce plugin is not active.
    */
    function cpb_addon_base_plugin_inactive_notice()
    {
        $message = sprintf(__('%s %s is inactive.%s Install and activate %sWooCommerce%s for %s to work.', 'custom-product-boxes'), '<strong>', EDD_WCPB_ITEM_NAME, '</strong>', '<a href="http://wordpress.org/extend/plugins/woocommerce/">', '</a>', EDD_WCPB_ITEM_NAME);
        printAdminNotices($message, 'error');
    }
}

if (! function_exists('cpb_subscription_not_active')) {
    function cpb_subscription_not_active()
    {
        $message = sprintf(__('%s %s is inactive.%s Install and activate %sWooCommerce%s for %s to work with %s.', 'custom-product-boxes'), '<strong>', "WooCommerce Subscriptions", '</strong>', '<a href="http://woocommerce.com/products/woocommerce-subscriptions/">', '</a>', "Subscription Model", EDD_WCPB_ITEM_NAME);
        printAdminNotices($message, 'notice-warning');
    }
}

function is_session_started()
{
    if (php_sapi_name() !== 'cli') {
        if (version_compare(phpversion(), '5.4.0', '>=')) {
            return session_status() === PHP_SESSION_ACTIVE ? true : false;
        } else {
            return session_id() === '' ? false : true;
        }
    }
    return false;
}

function cpbGetTemplate($file, $data, $empty, $path)
{
    return wc_get_template($file, $data, $empty, $path);
}

/**
* If the pre-filled products are allowed then return true else false.
* @return bool true if pre-filled boxes allowed else false.
*/
function allowPrefillProducts()
{
    $allowPrefillProducts = get_post_meta(get_the_ID(), 'wdm_prefilled_box', true);
    if ($allowPrefillProducts == 'yes') {
        return true;
    }
    return false;
}

function isSubscriptionActive()
{
    return in_array('woocommerce-subscriptions/woocommerce-subscriptions.php', apply_filters('active_plugins', get_option('active_plugins')));
}

function isProductCPBSubscription($postId)
{
    return isSubscriptionActive() && get_post_meta($postId, 'wdm_enable_product_subscription', true) == 'yes';
}

function isEditProductPage()
{
    $screen       = get_current_screen();
    $screen_id    = $screen ? $screen->id : '';
    return in_array($screen_id, array('product', 'edit-product'));
}

function getLastOrderNumber()
{
    if (get_option('wdmcpb_last_order_updated') == 'no') {
        return false;
    }

    global $wpdb;
    $orderNumber = get_option('wdmcpb_last_order_id');

    $query = "SELECT * FROM 
    `".$wpdb->prefix."woocommerce_order_items` ORDER BY `".$wpdb->prefix."woocommerce_order_items`.`order_id` DESC LIMIT 1";

    $orderResult = $wpdb->get_row($query);

    if (!$orderResult) {
        return false;
    }

    $orderId = $orderResult->order_id;

    return !empty($orderNumber) ? $orderNumber : $orderId;
}

/*
 * get box product or id if 2nd parameter is provided
 * $addonId unique id of add-on product
 * $boxid boolean true if box id is required
 * return product or id of box product.
*/
// function getBoxProduct($addonId, $boxid = false)
// {

// }

/*
  * True if a cart item is included in a box
 * @return boolean
 */
function isIncludedInBox($cart_item)
{

    $isncluded = false;

    if (! empty($cart_item[ 'wdm_custom_bundled_by' ]) && ! empty($cart_item[ 'bundled_item_id' ]) && ! empty($cart_item[ 'wdm_custom_stamp' ])) {
        $isncluded = true;
    }

    return $isncluded;
}

function getCartAddonItemBox($addonCartItem, $cart_contents = false, $boxid = false)
{
    if (! $cart_contents) {
        if (property_exists(WC()->cart, 'cart_contents') && empty(WC()->cart->cart_contents)) {
            return false;
        }
        $cart_contents = WC()->cart->cart_contents;
    }

    $container = false;

    if (isIncludedInBox($addonCartItem)) {
        $bundled_by = $addonCartItem[ 'wdm_custom_bundled_by' ];

        if (isset($cart_contents[ $bundled_by ])) {
            $container = $boxid ? $bundled_by : $cart_contents[ $bundled_by ]['data'];
        }
    }

    return $container;
}

function getExistingMsgLabels()
{
    if (get_option('wdmcpb_old_order_labels')) {
        return maybe_unserialize(
            get_option('wdmcpb_old_order_labels')
        );
    }

    $cpbIds = getCPBProductIds();
    $existingLabels = array();
    if (empty($cpbIds)) {
        return array();
    }

    foreach ($cpbIds as $id) {
        if ("yes" != get_post_meta($id, '_wdm_enable_gift_message', true)) {
            continue;
        }

        array_push($existingLabels, get_post_meta($id, '_wdm_gift_message_label', true));
    }

    return $existingLabels;
}

/*
 * Returns array of id's for all the available CPB product type products on the site
*/
function getCPBProductIds()
{
    global $wpdb;
    // $args = array(
    //     'post_type' => 'product',
    //     'post_status' => 'publish',
    //     'fields' => 'ids',
    //     'tax_query' => array(
    //         array(
    //             'taxonomy' => 'product_type',
    //             'field' => 'slug',
    //             'terms' => 'wdm_bundle_product',
    //             'compare' => '=',
    //         )
    //     )
    // );

    $query = "SELECT post_id FROM ".$wpdb->prefix."postmeta WHERE `meta_key` = '_bundle_data'";
    $postIds = $wpdb->get_col($query);

    return $postIds;
}

function isCpbFreshInstall()
{
    return version_compare(CPB_VERSION, get_option('wdmcpb_start_version'), '==');
}

function hasWcOrders()
{
    global $wpdb;
    $query = "SELECT * FROM 
    `".$wpdb->prefix."woocommerce_order_items` ORDER BY `".$wpdb->prefix."woocommerce_order_items`.`order_id` DESC LIMIT 1";

    $orderResult = $wpdb->get_row($query);

    if ($orderResult) {
        return true;
    }

    return false;
}

/**
 * This function is used to display helptip.
 *
 * @param [String] $helptip  [Help tip to be displayed]
 * @param bool     $settings [description]
 * @param string   $image    [alternate for image]
 * @param string   $title    [title for help tip]
 *
 * @return [HTML string] [helptip]
 */
function cpbHelpTip($helptip, $settings = false, $image = '', $title = '')
{
    if ($settings === true) {
        $wooVersion = WC_VERSION;
        $wooVersion = floatval($wooVersion);
        $value = '';
        if ($wooVersion < 2.5) {
            $value = '<img class="help_tip" data-tip="'.esc_attr($helptip).'" src="'.WC()->plugin_url().'/assets/images/help.png" height="16" width="16" />';
        } else {
            $value = \wc_help_tip($helptip);
        }
        
        return $value;
    }
    if (!empty($image)) {
        return '<img class="help_tip tips" alt="'.esc_attr($title).'" data-tip="'.esc_attr($helptip).'" src="'.$image.'" height="25" width="25" />';
    }

    return '<span class="help_tip tips" data-tip="'.esc_attr($helptip).'">'.esc_attr($title).'</span>';
}

function getPrefillBundleForVariableProduct($bundleData)
{
    if (empty($bundleData) || !is_array($bundleData)) {
        return $bundleData;
    }

    foreach ($bundleData as $singleKey => $singleData) {
        if ($singleData['product_type'] == "variable") {
            foreach ($singleData['childrens'] as $variationData) {
                $variationDataArray = (array) $variationData;
                $bundleData[$variationDataArray['id']] = $variationDataArray;
            }
            unset($bundleData[$singleKey]);
        }
    }

    return $bundleData;
}

function getDisplayName($productId, $item_data, $product)
{
    $productTitle = get_the_title($productId);

    if (getProductType($product) == "variation") {
        $variationProduct = new \WC_Product_Variation($productId);
        $variationAttributes = $variationProduct->get_variation_attributes();
        if (checkAnyAnyVariation($variationAttributes)) {
            $variation = $item_data['variation_string'];
            $productTitle .= "&#8211;". $variation;
        }
    }

    return $productTitle;
}


function subscriptionContainsCPB($subscription)
{
    $line_items = $subscription->get_items();
    foreach ($line_items as $key => $sub_item) {
        unset($key); //unused
        if ($sub_item['product_id']) {
            $box = wc_get_product($sub_item['product_id']);
            if ($box->is_type('wdm_bundle_product')) {
                return true;
            }
        }
    }

    return false;
}

/**
 * Removes the deleted products data from the CPB Product
 * If the products are deleted from the Woocommerce products list and still
 * present in the CPB Product delete those products.
 * @param  array $product_field_types array of products bundled in CPB product
 * @param int $postId
 * @return array $product_field_types array of products bundled in CPB product
 * excluding the products which are deleted from DB.
 */
function unlinkDeletedProducts($addOnProducts, $postId)
{
    global $prefillManager;
    static $allProducts = array();

    if (get_post_meta($postId, '_per_product_pricing_active', true) == 'no' && get_post_meta($postId, '_product_base_pricing_active', true) == 'no') {
        update_post_meta($postId, '_product_base_pricing_active', 'yes');
    }

    // if (get_post_meta($postId, '_product_base_pricing_active', true) == 'no' && get_post_meta($postId, '_per_product_pricing_active', true) == 'yes') {
    //     update_post_meta($postId, '_price', get_post_meta($postId, '_regular_price', true));
    // }

    if (empty($allProducts)) {
        global $wpdb;
        $postsTable = $wpdb->prefix . 'posts';
        $allProducts = $wpdb->get_col("SELECT ID FROM $postsTable WHERE post_type IN ('product', 'product_variation')");
    }

    $cpb_keys = getBundledIds($addOnProducts);
    $prefillData = $prefillManager->getPrefilledProducts($postId);

    if ($cpb_keys && $allProducts) {
        $deletedProducts = array_diff($cpb_keys, $allProducts);
        if ($deletedProducts) {
            foreach ($deletedProducts as $deletedKey) {
                $addOnProducts = unsetDeletedProduct($addOnProducts, $deletedKey);
                    unsetDeletedPrefillProducts($prefillData, $deletedKey, $postId);
            }
        }

        $addOnProducts = getModifiedTextAddOnProducts($addOnProducts);

        update_post_meta($postId, '_bundle_data', $addOnProducts);
    }

    return $addOnProducts;
}

function getModifiedTextAddOnProducts($addOnProducts)
{
    foreach ($addOnProducts as $key => $value) {
        $productSku = get_post_meta($value['product_id'], '_sku', true);
        $productId = isset($value['variation_id']) ? $value['variation_id'] : $value['product_id'];
        $value['text'] = getDynamicName($productId, $value, $productSku);
        $addOnProducts[$key] = $value;
        $product = wc_get_product($productId);
        $addOnProducts[$key]['price'] = wc_get_price_to_display($product);

        if (getProductType($product) == "variation" || getProductType($product) == "simple") {
            $addOnProducts[$key]['display_text'] = getDisplayName($productId, $value, $product);
        }
        if (getProductType($product) == "variable") {
            $addOnProducts = getTextForVariableAddonProducts($value, $addOnProducts, $key);
        }
    }

    return $addOnProducts;
}

function getTextForVariableAddonProducts($value, $addOnProducts, $key)
{
    foreach ($value['childrens'] as $childKey => $child) {
        $childProductId = isset($child['variation_id']) ? $child['variation_id'] : $child['product_id'];
        $childProduct = wc_get_product($childProductId);

        $addOnProducts[$key]['childrens'][$childKey]['display_text'] = getDisplayName($childProductId, $child, $childProduct);
    }

    return $addOnProducts;
}


function getDynamicName($productId, $item_data, $productSku)
{
    $product = wc_get_product($productId);
    $productTitle = get_the_title($productId);

    if (getProductType($product) == "variation") {
        $variationProduct = new \WC_Product_Variation($productId);
        $variationAttributes = $variationProduct->get_variation_attributes();
        if (checkAnyAnyVariation($variationAttributes)) {
            $variation = $item_data['variation_string'];
            $skuString = isset($productSku) && !empty($productSku) ? $productSku : "#".$productId;
            $productTitle .= "&#8211;". $variation . "(". $skuString . ")";
        } else {
            $skuString = isset($productSku) && !empty($productSku) ? $productSku : "#".$productId;
            $productTitle .= "(". $skuString . ")";
        }
    } else {
        $skuString = isset($productSku) && !empty($productSku) ? $productSku : "#".$productId;
        $productTitle .= "(". $skuString . ")";
    }

    return $productTitle;
}

function unsetDeletedPrefillProducts($prefillData, $deletedKey, $cpbId)
{
    global $prefillManager, $wpdb;
    if (empty($prefillData) || !is_array($prefillData) || empty($deletedKey)) {
        return $prefillData;
    }

    foreach ($prefillData as $key => $value) {
        unset($key);
        $product_id = isset($value['product_id']) ? $value['product_id'] : "";
        if ($product_id == $deletedKey) {
            $wpdb->delete(
                $prefillManager->prefillProductTable,
                array(
                    'cpb_product_id'        => $cpbId,
                    'unique_prod_id'        => $value['unique_prod_id'],
                ),
                array(
                    '%d',
                    '%s',
                )
            );
        }
    }
}

function unsetDeletedProduct($addOnProducts, $deletedKey)
{
    if (empty($addOnProducts) || !is_array($addOnProducts)) {
        return $addOnProducts;
    }

    foreach ($addOnProducts as $key => $value) {
        $product_id = isset($value['variation_id']) ? $value['variation_id'] : $value['product_id'];
        if ($product_id == $deletedKey) {
            unset($addOnProducts[$key]);
        }
    }

    return $addOnProducts;
}

/**
* Returns the Product id for simple product.
* Returns variation id for variable product.
* @param object $productObject Product Object.
* @param string $context view
*/
function getProductId($productObject, $context = 'view')
{

    if (is_callable(array($productObject, 'get_id'))) {
        return $productObject->get_id($context);
    }
    return isset($product->variation_id)? $product->variation_id : $product->id;
}


function getBundledIds($bundleData)
{
    $bundleIds = array();
    foreach ($bundleData as $key => $value) {
        unset($key);
        array_push($bundleIds, isset($value['variation_id']) ? $value['variation_id'] : $value['product_id']);
    }

    return $bundleIds;
}

    /**
 * Returns true if WPML is active. Else returns false.
 * @return bool
 */
function cpbIsWpmlActive()
{
    if (!defined('ICL_SITEPRESS_VERSION') || ICL_PLUGIN_INACTIVE) {
        return false;
    }
    
    return true;
}

/**
 * Returns Attribute Name for variations which are not Taxonomies.
 * @param string $variableProduct Variable Product
 * @param string $variationAttribute Variation attribute
 * @param array $allAttributes ALL variation attributes
 * @return string $label label for variation
 */
function cpbVariationAttributeLabel($variableProduct, $variationAttribute, $allAttributes)
{
    if (version_compare(WC_VERSION, '3.0.0', '<')) {
        if (isset($allAttributes[ str_replace('attribute_', '', $variationAttribute) ])) {
            $label = wc_attribute_label($allAttributes[ str_replace('attribute_', '', $variationAttribute) ]['name']);
        } else {
            $label = $variationAttribute;
        }
    } else {
        $label = wc_attribute_label(str_replace('attribute_', '', $variationAttribute), $variableProduct);
    }
    return $label;
}

/**
* This function return the variation details appended in a string format.
* @param array $variation_data Variation details
* @param array $variableProduct Variable product details
* @param array $product_attributes Product variation attributes
* @return string $variationToBeSent Variation to be sent.
*/
function getCpbVariationString($variation_data, $variableProduct, $product_attributes)
{
    $variationToBeSent = '';
    foreach ($variation_data as $name => $value) {
        $taxonomy = wc_attribute_taxonomy_name(str_replace('attribute_pa_', '', urldecode($name)));

            // If this is a term slug, get the term's nice name
        if (taxonomy_exists($taxonomy)) {
            $term = get_term_by('slug', $value, $taxonomy);
            if (!is_wp_error($term) && $term && $term->name) {
                $value = $term->name;
            }
            $label = wc_attribute_label($taxonomy);
            // If this is a custom option slug, get the options name
        } else {
            $label = cpbVariationAttributeLabel($variableProduct, $name, $product_attributes);
        }

        if (!empty($variationToBeSent)) {
            $variationToBeSent .= '';
        }

        $variationToBeSent .= $label.': '.stripcslashes($value).", ";
    }

    return $variationToBeSent;
}

function getProductType($product, $product_id = null)
{
    if ($product_id != null) {
        $product = wc_get_product($product_id);
    }

    if (!$product) {
        return false;
    }

    if (version_compare(WC_VERSION, '3.0', '<')) {
        return $product->product_type;
    } else {
        return $product->get_type();
    }
}

/*
 * Below we will be calling get_variation_attributes function which makes a call to get_attributes.
 * get_variation_attributes uses name of attribute as a key in the returned array. We need to change the
 * behavior and we need to have a 'slug' as a key in the array returned by get_variation_attributes.
 * Therefore, we'll change the array returned by get_attributes. We'll keep name as slug in
 * get_attributes array
 */
function cpbModifyProductAttributeNames($attributes)
{
    
    if (version_compare(WC_VERSION, '3.0.0', '<')) {
        if (is_array($attributes)) {
            foreach ($attributes as $attributeSlug => $attributeData) {
                $attributes[$attributeSlug]['name'] = $attributeSlug;
                unset($attributeData);
            }
        }
    } else {
        //For 3.0 and greater
        if (is_array($attributes)) {
            foreach ($attributes as $attributeSlug => $attributeObject) {
                $attributeData = $attributeObject->get_data();
                if ($attributeData['is_variation']) {
                    $attributes[$attributeSlug] = $attributeObject->get_slugs();
                } else {
                    unset($attributes[$attributeSlug]);
                }
            }
        }
    }

    return $attributes;
}


function checkAnyAnyVariation($attributes)
{
    foreach ($attributes as $key => $value) {
        unset($key);
        if (empty($value)) {
            return true;
        }
    }
}
