<?php

namespace wisdmlabs\cpb;

/**
* This class is responsible to display the products for mobile layout.
*/

class WdmCPBMobileListLayout extends WdmAbstractProductDisplay
{
    /**
    * Action for enqueuing scripts and styles for the mobile layout of the CPB.
    * Action to display the products on mobile layout.
    */
    public function __construct()
    {
        parent::__construct();
        add_action('wdm_cpb_mobile_enqueue_styles', array($this,'enqueueStyles'));
        add_action('wdm_cpb_mobile_product_layout', array($this, 'displayAddToCartForm'));
        add_action('wdm_mobile_product_price_html', array($this, 'cpbMobileTemplateSinglePrice'), 10);
        add_action('wdm_cpb_mobile_enqueue_scripts', array($this, 'enqueueScripts'));
    }
    /**
    * Returns the path for selected template.
    * @param string $templateType type for selected template.
    * @return string $templateType path for selected template.
    */
    public function __get($templateType)
    {
        $this->$templateType = 'product-layouts/mobile-layouts/list/' . parent::__get($templateType);
        return $this->$templateType;
    }

    /**
    * Enqueue styles for mobile layouts of CPB product display.
    * Sets the layout breakpoint screen resolution for the mobile layout.
    */
    public function enqueueStyles()
    {
        global $woo_wdm_bundle;
        wp_enqueue_style('wdm-cpb-mobile-list-layout-css', $woo_wdm_bundle->pluginUrl() . '/assets/css/mobile-templates/list-layout.css', array(), CPB_VERSION, self::setMobileLayoutBreakpoint());
        wp_enqueue_style('wdm-cpb-snackbar-css', $woo_wdm_bundle->pluginUrl() . '/assets/css/wdm-snackbar.css', array(), CPB_VERSION);
    }

    /**
    * Enqueue scripts for mobile layout.
    * Prepare data for localization passed to mobile list layout js.
    */
    public function enqueueScripts()
    {
        global $woo_wdm_bundle;
        wp_enqueue_script('wdm-cpb-mobile-list-layout-js', $woo_wdm_bundle->pluginUrl() . '/assets/js/mobile-templates/list-layout.js', array('jquery'), CPB_VERSION);
        wp_enqueue_script('wdm-cpb-snackbar-js', $woo_wdm_bundle->pluginUrl() . '/assets/js/snackbar/snackbar.js', array('jquery'), CPB_VERSION);
        wp_localize_script('wdm-cpb-mobile-list-layout-js', 'mobileListLayoutParams', array(
            'enableProductsSwap'    => $this->enableSwapping() === true ? 1 : 0,
            'giftboxFullMsg'        => __('Gift Box is full.', 'custom-product-boxes'),
            'canNotAddProduct'      => __('Another %s can not be added to the box', 'custom-product-boxes'),
            'productsAddedText'     => __('Products in Box.', 'custom-product-boxes'),
            'totalProductPriceText' => __('Total Product Price', 'custom-product-boxes'),
        ));
        //wp_localize_script('wdm-add-to-cart-bundle', 'wdm_bundle_params', $params);
    }
}
